package cz.iivos.pjj.weather;

import java.util.ArrayList;
import java.util.List;
import javax.swing.AbstractListModel;

public class WeatherListModel extends AbstractListModel {

	/**
	 * Prvky uložené v tomto modelu.
	 */
	private List<WeatherBean> list;

	/**
	 * Vytvoří prázdnou instanci třídy WeatherListModel.
	 */
	public WeatherListModel() {
		list = new ArrayList<WeatherBean>();
	}

	/**
	 * Vytvoří instanci třídy WeatherListModel s prvky v předaném
	 * seznamu elementList.
	 * 
	 * @param elementList
	 *            seznam prvků v nově vytvářeném modelu.
	 */
	public WeatherListModel(List<WeatherBean> elementList) {
		list = new ArrayList<WeatherBean>(elementList);
	}

	@Override
	public int getSize() {
		return list.size();
	}

	@Override
	public Object getElementAt(int index) {
		return list.get(index);
	}

	/**
	 * Přidá do zobrazovaného seznamu prvek element.
	 * 
	 * @param element
	 *            přidávaný prvek.
	 */
	public void add(WeatherBean element) {
		list.add(element);
		fireIntervalAdded(this, list.size(), list.size());
	}

	/**
	 * Odstraní ze zobrazovaného seznamu prvek element.
	 * 
	 * @param element
	 *            odebíraný prvek.
	 */
	public void remove(Object element) {
		int index = list.indexOf(element);

		if (index != -1) {
			list.remove(element);
			fireIntervalRemoved(this, index, index);
		}
	}

	/**
	 * Odstraní ze seznamu všechny prvky.
	 */
	public void clear() {
		int size = list.size();
		list.clear();
		fireContentsChanged(this, 0, size);
	}

}
